@@ -1,7 +1,7 @@
-
 context("is_too_many")
 
 test_that("is_too_many gives reasonable info", {
+    skip_on_cran()
 
     # shorter delay to speed tests
     old_delay <- getOption("aRxiv_delay")
@@ -17,6 +17,7 @@ test_that("is_too_many gives reasonable info", {
 })
 
 test_that("arxiv_search throws error with huge result", {
+    skip_on_cran()
 
     # shorter delay to speed tests
     old_delay <- getOption("aRxiv_delay")
@@ -24,5 +25,5 @@ test_that("arxiv_search throws error with huge result", {
     options(aRxiv_delay=0.5)
 
     # should give error, to prevent huge result
-    expect_error(arxiv_search("au:A", limit=NULL))
+    suppressMessages(expect_error(arxiv_search("au:A", limit=NULL)))
 })
